function dt = chamferTransform(sil,rad)

% function dt = chamferTransform(sil,rad)
%
% Takes a binary silhouette and produces a distance transform
% suitable for use with chamferDistance.
% The default padding radius is one-half the original size.
%
% See also chamferDistance.

if strcmp('uint8',class(sil))
    sil = unchain(sil);
end;

if (nargin < 2)
    ss = size(sil);
    rad = round(ss/2);
end;

pad = colfilt(padarray(sil,rad),[2 2],'sliding',@(x) any(x));
pad = pad(1:end-1,1:end-1);  % remove extra padding from colfilt
out = pad-imerode(pad,strel('square',3));
dt = bwdist(out);  % BWDIST requires image processing toolbox.
